Vs1003InterfaceError

Enum Vs1003InterfaceError 

pub enum Vs1003InterfaceError<ESpi, EDreq> {
    Spi(ESpi),
    Dreq(EDreq),
    Busy,
}
The error type that can be returned by various interface APIs

Variants



Spi(ESpi)

The SPI peripheral has failed to compelte a transfer



Dreq(EDreq)

The Digital input failed to provide a value



Busy

The DREQ signal is low and the command cannot be sent