DecodeTime

Struct DecodeTime 

pub struct DecodeTime { /* private fields */ }
The current decode time in full seconds.

The user may change the value of this register. In that case the new value should be written twice.

Implementations

Source

impl DecodeTime

pub const fn new() -> Self

Create a new instance, loaded with the reset value (if any)

pub const fn new_zero() -> Self

Create a new instance, loaded with all zeroes

pub fn value(&self) -> u16

Read the value field of the register.

The current decode time in seconds.

pub fn set_value(&mut self, value: u16)

Write the value field of the register.

The current decode time in seconds.