pub enum FieldSetValue {
}Expand description
Enum containing all possible field set types
Variants
Raw(Raw)
Access any register to read or write a custom value.
This is especially useful when uploading plugins as they are specified in register address + value to write format.
Mode(Mode)
The SCI_MODE register - controls various aspects of operation of the VS1003
Status(Status)
The SCI_STATUS register
Bass(Bass)
Bass enhancer settings
Clockf(Clockf)
Register responsible for controlling the clock settings
DecodeTime(DecodeTime)
The current decode time in full seconds.
The user may change the value of this register. In that case the new value should be written twice.
Audata(Audata)
Contains information about the sample rate and number of channels.
Can be written to overwrite the information.
Wram(Wram)
Wram is used to upload application programs and data to instruction and data RAMs. The start address must be initialized by writing to WramAddr prior to the first write/read of Wram. As 16 bits of data can be transferred with one Wram write/read, and the instruction word is 32 bits long, two consecutive writes/reads are needed for each instruction word. The byte order is big-endian (i.e. most significant words first). After each full-word write/read, the internal pointer is autoincremented.
WramAddr(WramAddr)
WramAddr is used to set the program address for following Wram writes/reads. Address offset of 0 is used for X, 0x4000 for Y, and 0x8000 for instruction memory. Peripheral registers can also be accessed
Hdat0(Hdat0)
Value depends on decoded file type and running application. Check the datasheet for details.
Hdat1(Hdat1)
Value depends on decoded file type and running application. Check the datasheet for details.
AiAddr(AiAddr)
AiAddr indicates the start address of the application code written earlier with WramAddr and Wram registers. If no application code is used, this register should not be initialized, or it should be initialized to zero. For more details, see Application Notes for VS10XX.
Vol(Vol)
Volume control.
Setting both channels to 255 will activate analog powerdown mode.
AiCtrl(AiCtrl)
For communication with user’s application on the VS1003