pub struct DecodeTime { /* private fields */ }Expand description
The current decode time in full seconds.
The user may change the value of this register. In that case the new value should be written twice.
Implementations